"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var nativescript_permissions_1 = require("nativescript-permissions");
var application_1 = require("@nativescript/core/application");
var Intent = android.content.Intent;
var PendingIntent = android.app.PendingIntent;
var GoogleApiAvailability = com.google.android.gms.common.GoogleApiAvailability;
var OnSuccessListener = com.google.android.gms.tasks.OnSuccessListener;
var OnFailureListener = com.google.android.gms.tasks.OnFailureListener;
var AndroidAbstractRecognizerManager = (function () {
    function AndroidAbstractRecognizerManager(receiver) {
        this.receiver = receiver;
    }
    AndroidAbstractRecognizerManager.prototype.isReady = function () {
        if (!isGooglePlayServicesAvailable()) {
            return false;
        }
        if (android.os.Build.VERSION.SDK_INT < 29) {
            return true;
        }
        return nativescript_permissions_1.hasPermission(android.Manifest.permission.ACTIVITY_RECOGNITION);
    };
    AndroidAbstractRecognizerManager.prototype.prepare = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!!isGooglePlayServicesAvailable()) return [3, 2];
                        return [4, promisify(GoogleApiAvailability.getInstance().makeGooglePlayServicesAvailable(application_1.android.foregroundActivity))];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (android.os.Build.VERSION.SDK_INT < 29) {
                            return [2];
                        }
                        if (!!nativescript_permissions_1.hasPermission(android.Manifest.permission.ACTIVITY_RECOGNITION)) return [3, 4];
                        return [4, nativescript_permissions_1.requestPermission(android.Manifest.permission.ACTIVITY_RECOGNITION)];
                    case 3:
                        _a.sent();
                        _a.label = 4;
                    case 4: return [2];
                }
            });
        });
    };
    AndroidAbstractRecognizerManager.prototype.startListening = function (options) {
        if (options === void 0) { options = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var task;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.isUp()) return [3, 2];
                        return [4, this.stopListening()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (!this.isReady()) {
                            throw new Error("Manager is not ready!. Call isReady() before start listening.");
                        }
                        task = this.handleStart(application_1.android.context, this.getPendingIntent(), options);
                        return [4, promisify(task)];
                    case 3:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    AndroidAbstractRecognizerManager.prototype.stopListening = function () {
        return __awaiter(this, void 0, void 0, function () {
            var pendingIntent, task;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.isUp()) {
                            return [2];
                        }
                        pendingIntent = this.getPendingIntent();
                        task = this.handleStop(application_1.android.context, pendingIntent);
                        pendingIntent.cancel();
                        this.pendingIntent = null;
                        return [4, promisify(task)];
                    case 1:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    AndroidAbstractRecognizerManager.prototype.isUp = function () {
        var pendingIntent = PendingIntent.getBroadcast(application_1.android.context, 0, this.getReceiverIntent(), PendingIntent.FLAG_NO_CREATE);
        return pendingIntent !== null;
    };
    AndroidAbstractRecognizerManager.prototype.getPendingIntent = function () {
        if (!this.pendingIntent) {
            var receiverIntent = this.getReceiverIntent();
            this.pendingIntent = PendingIntent.getBroadcast(application_1.android.context, 0, receiverIntent, 0);
        }
        return this.pendingIntent;
    };
    AndroidAbstractRecognizerManager.prototype.getReceiverIntent = function () {
        return new Intent(application_1.android.context, this.receiver);
    };
    return AndroidAbstractRecognizerManager;
}());
exports.AndroidAbstractRecognizerManager = AndroidAbstractRecognizerManager;
var CONNECTION_RESULT_SUCCESS = 0;
function isGooglePlayServicesAvailable() {
    return (GoogleApiAvailability.getInstance().isGooglePlayServicesAvailable(application_1.android.context) === CONNECTION_RESULT_SUCCESS);
}
function promisify(task) {
    return new Promise(function (resolve, reject) {
        task.addOnSuccessListener(getOnSuccessListener(resolve));
        task.addOnFailureListener(getOnFailureListener(reject));
    });
}
function getOnSuccessListener(onSuccess) {
    return new OnSuccessListener({
        onSuccess: onSuccess,
    });
}
function getOnFailureListener(onFailure) {
    return new OnFailureListener({
        onFailure: function (ex) {
            onFailure(new Error(ex.getMessage()));
        },
    });
}
//# sourceMappingURL=abstract-manager.android.js.map