"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AbstractActivityRecognizer = (function () {
    function AbstractActivityRecognizer(recognizerType, recognizerState, callbackManager, recognitionManager) {
        this.recognizerType = recognizerType;
        this.recognizerState = recognizerState;
        this.callbackManager = callbackManager;
        this.recognitionManager = recognitionManager;
    }
    AbstractActivityRecognizer.prototype.isReady = function () {
        return this.recognitionManager.isReady();
    };
    AbstractActivityRecognizer.prototype.prepare = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.recognitionManager.prepare()];
                    case 1:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    AbstractActivityRecognizer.prototype.setup = function () {
        return __awaiter(this, void 0, void 0, function () {
            var active, startOptions;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.recognizerState.isActive(this.recognizerType)];
                    case 1:
                        active = _a.sent();
                        if (!active) return [3, 4];
                        return [4, this.recognizerState.getStartOptions(this.recognizerType)];
                    case 2:
                        startOptions = _a.sent();
                        return [4, this.recognitionManager.startListening(startOptions)];
                    case 3:
                        _a.sent();
                        _a.label = 4;
                    case 4: return [2];
                }
            });
        });
    };
    AbstractActivityRecognizer.prototype.startRecognizing = function (options) {
        if (options === void 0) { options = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var active;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.recognitionManager.startListening(options)];
                    case 1:
                        _a.sent();
                        return [4, this.recognizerState.isActive(this.recognizerType)];
                    case 2:
                        active = _a.sent();
                        if (active) {
                            return [2];
                        }
                        return [4, this.recognizerState.markAsActive(this.recognizerType, options)];
                    case 3:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    AbstractActivityRecognizer.prototype.stopRecognizing = function () {
        return __awaiter(this, void 0, void 0, function () {
            var e_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4, this.recognitionManager.stopListening()];
                    case 1:
                        _a.sent();
                        return [3, 3];
                    case 2:
                        e_1 = _a.sent();
                        console.error("Could not deactivate " + this.recognizerType + " res activity recognizer: " + (e_1.stack ? e_1.stack : e_1));
                        return [3, 3];
                    case 3: return [4, this.recognizerState.markAsInactive(this.recognizerType)];
                    case 4:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    AbstractActivityRecognizer.prototype.listenActivityChanges = function (callback) {
        return this.callbackManager.add(callback);
    };
    AbstractActivityRecognizer.prototype.stopListening = function (listenerId) {
        if (typeof listenerId === "number") {
            this.callbackManager.remove(listenerId);
        }
        else {
            this.callbackManager.removeAll();
        }
    };
    return AbstractActivityRecognizer;
}());
exports.AbstractActivityRecognizer = AbstractActivityRecognizer;
//# sourceMappingURL=abstract-recognizer.js.map