"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable");
var eventName = "activityChanged";
var RecognizerCallbackManager = (function () {
    function RecognizerCallbackManager() {
        this.notificationCenter = observable_1.fromObject({});
        this.listenerCounter = 0;
        this.callbacks = new Map();
    }
    RecognizerCallbackManager.prototype.add = function (callback) {
        var callbackId = this.listenerCounter;
        var internalCallback = function (eventData) {
            return callback(eventData.data);
        };
        this.callbacks.set(callbackId, internalCallback);
        this.notificationCenter.on(eventName, internalCallback);
        return this.listenerCounter++;
    };
    RecognizerCallbackManager.prototype.notifyAll = function (activityChange) {
        if (!this.notificationCenter.hasListeners(eventName)) {
            return;
        }
        var eventData = {
            eventName: eventName,
            object: this.notificationCenter,
            data: __assign({}, activityChange),
        };
        this.notificationCenter.notify(eventData);
    };
    RecognizerCallbackManager.prototype.remove = function (callbackId) {
        if (!this.callbacks.has(callbackId)) {
            return;
        }
        var callback = this.callbacks.get(callbackId);
        this.notificationCenter.off(eventName, callback);
        this.callbacks.delete(callbackId);
    };
    RecognizerCallbackManager.prototype.removeAll = function () {
        this.notificationCenter.off(eventName);
        this.callbacks.clear();
    };
    return RecognizerCallbackManager;
}());
exports.RecognizerCallbackManager = RecognizerCallbackManager;
//# sourceMappingURL=callback-manager.js.map