"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ActivityRecognitionResult = com.google.android.gms.location.ActivityRecognitionResult;
var DetectedActivity = com.google.android.gms.location.DetectedActivity;
var recognizer_android_1 = require("./recognizer.android");
var utils_android_1 = require("../../utils.android");
var AndroidActivityUpdateReceiver = (function () {
    function AndroidActivityUpdateReceiver() {
    }
    AndroidActivityUpdateReceiver.prototype.onReceive = function (context, intent) {
        if (!ActivityRecognitionResult.hasResult(intent)) {
            return;
        }
        var result = ActivityRecognitionResult.extractResult(intent);
        var recognizer = recognizer_android_1.getAndroidMediumResRecognizer();
        var mostProbableActivity = result.getMostProbableActivity();
        if (mostProbableActivity.getType() === DetectedActivity.UNKNOWN) {
            return;
        }
        var activityUpdate = {
            type: utils_android_1.activityTypeToHumanActivity(mostProbableActivity.getType()),
            confidence: mostProbableActivity.getConfidence() / 100.0,
            timestamp: utils_android_1.elapsedRealtimeToDate(result.getElapsedRealtimeMillis() * 1e6),
        };
        recognizer.onRecognitionResult(activityUpdate).catch(function (err) {
            console.error("MediumResRecognizer. Recognition error: " + err);
        });
    };
    return AndroidActivityUpdateReceiver;
}());
exports.AndroidActivityUpdateReceiver = AndroidActivityUpdateReceiver;
var _updateReceiver;
function getAndroidActivityUpdateReceiver() {
    if (!_updateReceiver) {
        _updateReceiver = new AndroidActivityUpdateReceiver();
    }
    return _updateReceiver;
}
exports.getAndroidActivityUpdateReceiver = getAndroidActivityUpdateReceiver;
//# sourceMappingURL=receiver.android.js.map