"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var adapter_1 = require("./adapter");
var geolocation_1 = require("./geolocation");
var rxjs_1 = require("rxjs");
var SECONDS = 1e3;
var MINUTES = 60 * SECONDS;
var defaultAccuracy = adapter_1.Accuracy.high;
var defaultInterval = MINUTES;
var defaultMinInterval = 5 * SECONDS;
var defaultTimeout = 5 * MINUTES;
var allowBackgroundByDefault = false;
var saveBatteryByDefault = true;
var GeolocationProvider = (function () {
    function GeolocationProvider(adapter) {
        this.adapter = adapter;
    }
    GeolocationProvider.prototype.isReady = function () {
        return this.adapter.isReady();
    };
    GeolocationProvider.prototype.prepare = function (watchAlways, openSettingsIfDenied) {
        if (watchAlways === void 0) { watchAlways = false; }
        if (openSettingsIfDenied === void 0) { openSettingsIfDenied = false; }
        return this.adapter.prepare(watchAlways, openSettingsIfDenied);
    };
    GeolocationProvider.prototype.acquireLocation = function (options) {
        if (options === void 0) { options = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var location;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.adapter.acquireLocation(geolocationOptionsToPluginOptions(options))];
                    case 1:
                        location = _a.sent();
                        return [2, new geolocation_1.Geolocation(location)];
                }
            });
        });
    };
    GeolocationProvider.prototype.locationStream = function (options) {
        var _this = this;
        if (options === void 0) { options = {}; }
        return new rxjs_1.Observable(function (subscriber) {
            var listenerId = _this.adapter.listenChanges(function (location) { return subscriber.next(new geolocation_1.Geolocation(location)); }, function (err) { return subscriber.error(err); }, geolocationOptionsToPluginOptions(options));
            return function () { return _this.adapter.stopListening(listenerId); };
        });
    };
    return GeolocationProvider;
}());
exports.GeolocationProvider = GeolocationProvider;
var geolocation_2 = require("./geolocation");
exports.Geolocation = geolocation_2.Geolocation;
function geolocationOptionsToPluginOptions(options) {
    var pluginOptions = {
        desiredAccuracy: "highAccuracy" in options ? adapter_1.Accuracy.any : defaultAccuracy,
        updateTime: "stdInterval" in options ? options.stdInterval : defaultInterval,
        minimumUpdateTime: "minInterval" in options ? options.minInterval : defaultMinInterval,
        timeout: "timeout" in options ? options.timeout : defaultTimeout,
        iosAllowsBackgroundLocationUpdates: "allowBackground" in options
            ? options.allowBackground
            : allowBackgroundByDefault,
        iosPausesLocationUpdatesAutomatically: "saveBattery" in options ? options.saveBattery : saveBatteryByDefault,
    };
    if ("distanceFilter" in options) {
        pluginOptions.updateDistance = options.distanceFilter;
    }
    if ("maxAge" in options) {
        pluginOptions.maximumAge = options.maxAge;
    }
    return pluginOptions;
}
var _geolocationProvider;
function getGeolocationProvider() {
    if (!_geolocationProvider) {
        _geolocationProvider = new GeolocationProvider(new adapter_1.GeolocationAdapter());
    }
    return _geolocationProvider;
}
exports.getGeolocationProvider = getGeolocationProvider;
//# sourceMappingURL=index.js.map